searchData={"items":[{"type":"module","title":"Supabase.Storage","doc":"Supabase.Storage Elixir Package\n\nThis module provides integration with the Supabase Storage API, enabling developers\nto perform a multitude of operations related to buckets and objects with ease.","ref":"Supabase.Storage.html"},{"type":"module","title":"Usage - Supabase.Storage","doc":"You can start by creating or managing buckets:\n\n    Supabase.Storage.create_bucket(client, \"my_new_bucket\")\n\nOnce a bucket is set up, objects within the bucket can be managed:\n\n    Supabase.Storage.upload_object(client, \"my_bucket\", \"path/on/server.png\", \"path/on/local.png\")","ref":"Supabase.Storage.html#module-usage"},{"type":"module","title":"Examples - Supabase.Storage","doc":"Here are some basic examples:\n\n    # Removing an object\n    Supabase.Storage.remove_object(client, \"my_bucket\", \"path/on/server.png\")\n\n    # Moving an object\n    Supabase.Storage.move_object(client, \"my_bucket\", \"path/on/server1.png\", \"path/on/server2.png\")\n\nEnsure to refer to method-specific documentation for detailed examples and explanations.","ref":"Supabase.Storage.html#module-examples"},{"type":"module","title":"Permissions - Supabase.Storage","doc":"Do remember to check and set the appropriate permissions in Supabase to make sure that the\noperations can be performed without any hitches.","ref":"Supabase.Storage.html#module-permissions"},{"type":"function","title":"Supabase.Storage.create_bucket/3","doc":"Creates a new bucket in the current project given a map of attributes.","ref":"Supabase.Storage.html#create_bucket/3"},{"type":"function","title":"Params - Supabase.Storage.create_bucket/3","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `id`: A unique identifier for the bucket you are creating.\n- `options.public`: The visibility of the bucket. Public buckets don't require an authorization token to download objects, but still require a valid token for all other operations. By default, buckets are private.\n- `options.file_size_limit`: Specifies the max file size in bytes that can be uploaded to this bucket. The global file size limit takes precedence over this value. The default value is `nil`, which doesn't set a per bucket file size limit.\n- `options.allowed_mime_types`: Specifies the allowed mime types that this bucket can accept during upload. The default value is `nil`, which allows files with all mime types to be uploaded. Each mime type specified can be a wildcard, e.g. image/*, or a specific mime type, e.g. image/png.","ref":"Supabase.Storage.html#create_bucket/3-params"},{"type":"function","title":"Examples - Supabase.Storage.create_bucket/3","doc":"iex> Supabase.Storage.create_bucket(client, \"avatars\")\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.create_bucket(client, \"avatars\", %{file_size_limit: \"100mb\"})\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.create_bucket(client, \"avatars\")\n    {:error, %Supabase.Error{...}}","ref":"Supabase.Storage.html#create_bucket/3-examples"},{"type":"function","title":"Supabase.Storage.delete_bucket/2","doc":"Deletes a bucket in the current project. Notice that this also deletes all objects in the bucket.","ref":"Supabase.Storage.html#delete_bucket/2"},{"type":"function","title":"Params - Supabase.Storage.delete_bucket/2","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `id`: The unique identifier of the bucket you would like to empty.","ref":"Supabase.Storage.html#delete_bucket/2-params"},{"type":"function","title":"Examples - Supabase.Storage.delete_bucket/2","doc":"iex> Supabase.Storage.delete_bucket(client, \"avatars\")\n    {:ok, :deleted}\n\n    iex> Supabase.Storage.delete_bucket(client, \"avatars\")\n    {:error, %Supabase.Error{...}}","ref":"Supabase.Storage.html#delete_bucket/2-examples"},{"type":"function","title":"Supabase.Storage.empty_bucket/2","doc":"Empties a bucket in the current project. This action deletes all objects in the bucket.","ref":"Supabase.Storage.html#empty_bucket/2"},{"type":"function","title":"Params - Supabase.Storage.empty_bucket/2","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `id`: The unique identifier of the bucket you would like to empty.","ref":"Supabase.Storage.html#empty_bucket/2-params"},{"type":"function","title":"Examples - Supabase.Storage.empty_bucket/2","doc":"iex> Supabase.Storage.empty_bucket(client, \"avatars\")\n    {:ok, :emptied}\n\n    iex> Supabase.Storage.empty_bucket(client, \"avatars\")\n    {:error, %Supabase.Error{...}}","ref":"Supabase.Storage.html#empty_bucket/2-examples"},{"type":"function","title":"Supabase.Storage.from/2","doc":"Creates an instance of `Supabase.Storage` so you can interact with the\n`Supabase.Storage.File` API.","ref":"Supabase.Storage.html#from/2"},{"type":"function","title":"Params - Supabase.Storage.from/2","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `bucket_id`: The unique identifier of the Bucket to operate within","ref":"Supabase.Storage.html#from/2-params"},{"type":"function","title":"Supabase.Storage.get_bucket/2","doc":"Retrieves information about a bucket in the current project.","ref":"Supabase.Storage.html#get_bucket/2"},{"type":"function","title":"Params - Supabase.Storage.get_bucket/2","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `id`: The unique identifier of the bucket you would like to retrieve.","ref":"Supabase.Storage.html#get_bucket/2-params"},{"type":"function","title":"Examples - Supabase.Storage.get_bucket/2","doc":"iex> Supabase.Storage.retrieve_bucket_info(client, \"avatars\")\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.retrieve_bucket_info(client, \"non-existant\")\n    {:error, %Supabase.Error{...}}","ref":"Supabase.Storage.html#get_bucket/2-examples"},{"type":"function","title":"Supabase.Storage.list_buckets/1","doc":"Retrieves information about all buckets in the current project.","ref":"Supabase.Storage.html#list_buckets/1"},{"type":"function","title":"Params - Supabase.Storage.list_buckets/1","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.","ref":"Supabase.Storage.html#list_buckets/1-params"},{"type":"function","title":"Examples - Supabase.Storage.list_buckets/1","doc":"iex> Supabase.Storage.list_buckets(client)\n    {:ok, [%Supabase.Storage.Bucket{...}, ...]}\n\n    iex> Supabase.Storage.list_buckets(client)\n    {:error, %Supabase.Error{}}","ref":"Supabase.Storage.html#list_buckets/1-examples"},{"type":"type","title":"Supabase.Storage.t/0","doc":"Represent an instance of the Storage service to interact with\nthe `Supabase.Storage.File` API.\n\n- `bucket_id`: The id of the `Supabase.Storage.Bucket` to operate within.\n- `client`: The `Supabase.Client` being hold. (internal)","ref":"Supabase.Storage.html#t:t/0"},{"type":"function","title":"Supabase.Storage.update_bucket/3","doc":"Updates a bucket in the current project given a map of attributes.","ref":"Supabase.Storage.html#update_bucket/3"},{"type":"function","title":"Params - Supabase.Storage.update_bucket/3","doc":"- `client`: The `Supabase.Client` to use to interact with the Storage service.\n- `id`: A unique identifier for the bucket you are creating.\n- `options.public`: The visibility of the bucket. Public buckets don't require an authorization token to download objects, but still require a valid token for all other operations. By default, buckets are private.\n- `options.file_size_limit`: Specifies the max file size in bytes that can be uploaded to this bucket. The global file size limit takes precedence over this value. The default value is `nil`, which doesn't set a per bucket file size limit.\n- `options.allowed_mime_types`: Specifies the allowed mime types that this bucket can accept during upload. The default value is `nil`, which allows files with all mime types to be uploaded. Each mime type specified can be a wildcard, e.g. image/*, or a specific mime type, e.g. image/png.","ref":"Supabase.Storage.html#update_bucket/3-params"},{"type":"function","title":"Examples - Supabase.Storage.update_bucket/3","doc":"iex> Supabase.Storage.update_bucket(client, \"avatars\", %{public: true})\n    {:ok, %Supabase.Storage.Bucket{...}}\n\n    iex> Supabase.Storage.update_bucket(client, \"avatars\", %{public: true})\n    {:error, %Supabase.Error{...}}","ref":"Supabase.Storage.html#update_bucket/3-examples"},{"type":"behaviour","title":"Supabase.Storage.Behaviour","doc":"Defines Supabase Storage Client callbacks","ref":"Supabase.Storage.Behaviour.html"},{"type":"type","title":"Supabase.Storage.Behaviour.bucket_id/0","doc":"","ref":"Supabase.Storage.Behaviour.html#t:bucket_id/0"},{"type":"type","title":"Supabase.Storage.Behaviour.conn/0","doc":"","ref":"Supabase.Storage.Behaviour.html#t:conn/0"},{"type":"callback","title":"Supabase.Storage.Behaviour.create_bucket/3","doc":"","ref":"Supabase.Storage.Behaviour.html#c:create_bucket/3"},{"type":"callback","title":"Supabase.Storage.Behaviour.delete_bucket/2","doc":"","ref":"Supabase.Storage.Behaviour.html#c:delete_bucket/2"},{"type":"callback","title":"Supabase.Storage.Behaviour.empty_bucket/2","doc":"","ref":"Supabase.Storage.Behaviour.html#c:empty_bucket/2"},{"type":"callback","title":"Supabase.Storage.Behaviour.from/2","doc":"","ref":"Supabase.Storage.Behaviour.html#c:from/2"},{"type":"callback","title":"Supabase.Storage.Behaviour.get_bucket/2","doc":"","ref":"Supabase.Storage.Behaviour.html#c:get_bucket/2"},{"type":"callback","title":"Supabase.Storage.Behaviour.list_buckets/1","doc":"","ref":"Supabase.Storage.Behaviour.html#c:list_buckets/1"},{"type":"callback","title":"Supabase.Storage.Behaviour.update_bucket/3","doc":"","ref":"Supabase.Storage.Behaviour.html#c:update_bucket/3"},{"type":"module","title":"Supabase.Storage.BodyDecoder","doc":"Custom body decoder, tries to parse to a Storage entity or an Error","ref":"Supabase.Storage.BodyDecoder.html"},{"type":"module","title":"Supabase.Storage.Bucket","doc":"Represents a Bucket on Supabase Storage.\n\nThis module defines the structure and operations related to a storage bucket on Supabase.","ref":"Supabase.Storage.Bucket.html"},{"type":"function","title":"Supabase.Storage.Bucket.changeset/2","doc":"","ref":"Supabase.Storage.Bucket.html#changeset/2"},{"type":"type","title":"Supabase.Storage.Bucket.file_size_limit_t/0","doc":"A `FileSizeLimit` consists of:\n\n- `size`: The maximum file size limit itself as an integer.\n- `unit` The unit of the file size limit, can be: `:byte`, `:megabyte`, `:gigabyte` or `:terabyte`, defaults to `:byte`.","ref":"Supabase.Storage.Bucket.html#t:file_size_limit_t/0"},{"type":"function","title":"Supabase.Storage.Bucket.parse/1","doc":"","ref":"Supabase.Storage.Bucket.html#parse/1"},{"type":"type","title":"Supabase.Storage.Bucket.t/0","doc":"A `Bucket` consists of:\n\n- `id`: The unique identifier for the bucket.\n- `name`: The display name of the bucket.\n- `owner`: The owner of the bucket.\n- `file_size_limit`: The maximum file size allowed in the bucket. Can be `nil` for no limit.\n- `allowed_mime_types`: List of MIME types permitted in this bucket. Can be `nil` for no restrictions.\n- `created_at`: Timestamp indicating when the bucket was created.\n- `updated_at`: Timestamp indicating the last update to the bucket.\n- `public`: Boolean flag determining if the bucket is publicly accessible or not.","ref":"Supabase.Storage.Bucket.html#t:t/0"},{"type":"module","title":"Supabase.Storage.Bucket.FileSizeLimit","doc":"","ref":"Supabase.Storage.Bucket.FileSizeLimit.html"},{"type":"module","title":"Supabase.Storage.BucketHandler","doc":"Provides low-level API functions for managing Supabase Storage buckets.\n\nThe Elixir.Supabase.Storage.BucketHandler module offers a collection of functions that directly interact with the Supabase Storage API for managing buckets. This module works closely with the `Supabase.Fetcher` for sending HTTP requests.","ref":"Supabase.Storage.BucketHandler.html"},{"type":"module","title":"Caution - Supabase.Storage.BucketHandler","doc":"This module provides a low-level interface to Supabase Storage buckets and is designed for internal use by the `Supabase.Storage` module. Direct use is discouraged unless you need to perform custom or unsupported actions that are not available through the higher-level API. Incorrect use can lead to unexpected results or data loss.","ref":"Supabase.Storage.BucketHandler.html#module-caution"},{"type":"type","title":"Supabase.Storage.BucketHandler.bucket_id/0","doc":"","ref":"Supabase.Storage.BucketHandler.html#t:bucket_id/0"},{"type":"type","title":"Supabase.Storage.BucketHandler.bucket_name/0","doc":"","ref":"Supabase.Storage.BucketHandler.html#t:bucket_name/0"},{"type":"function","title":"Supabase.Storage.BucketHandler.create/2","doc":"","ref":"Supabase.Storage.BucketHandler.html#create/2"},{"type":"function","title":"Supabase.Storage.BucketHandler.delete/2","doc":"","ref":"Supabase.Storage.BucketHandler.html#delete/2"},{"type":"function","title":"Supabase.Storage.BucketHandler.empty/2","doc":"","ref":"Supabase.Storage.BucketHandler.html#empty/2"},{"type":"function","title":"Supabase.Storage.BucketHandler.list/1","doc":"","ref":"Supabase.Storage.BucketHandler.html#list/1"},{"type":"function","title":"Supabase.Storage.BucketHandler.retrieve_info/2","doc":"","ref":"Supabase.Storage.BucketHandler.html#retrieve_info/2"},{"type":"function","title":"Supabase.Storage.BucketHandler.update/3","doc":"","ref":"Supabase.Storage.BucketHandler.html#update/3"},{"type":"module","title":"Supabase.Storage.Endpoints","doc":"Defines the Endpoints for the Supabase Storage API","ref":"Supabase.Storage.Endpoints.html"},{"type":"function","title":"Supabase.Storage.Endpoints.bucket_path/0","doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path/0"},{"type":"function","title":"Supabase.Storage.Endpoints.bucket_path_to_empty/1","doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path_to_empty/1"},{"type":"function","title":"Supabase.Storage.Endpoints.bucket_path_with_id/1","doc":"","ref":"Supabase.Storage.Endpoints.html#bucket_path_with_id/1"},{"type":"function","title":"Supabase.Storage.Endpoints.file_copy/0","doc":"","ref":"Supabase.Storage.Endpoints.html#file_copy/0"},{"type":"function","title":"Supabase.Storage.Endpoints.file_download/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_download/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_info/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_info/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_list/1","doc":"","ref":"Supabase.Storage.Endpoints.html#file_list/1"},{"type":"function","title":"Supabase.Storage.Endpoints.file_move/0","doc":"","ref":"Supabase.Storage.Endpoints.html#file_move/0"},{"type":"function","title":"Supabase.Storage.Endpoints.file_remove/1","doc":"","ref":"Supabase.Storage.Endpoints.html#file_remove/1"},{"type":"function","title":"Supabase.Storage.Endpoints.file_signed_url/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_signed_url/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_upload/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_upload_signed_url/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload_signed_url/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_upload_to_url/2","doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload_to_url/2"},{"type":"function","title":"Supabase.Storage.Endpoints.file_upload_url/1","doc":"","ref":"Supabase.Storage.Endpoints.html#file_upload_url/1"},{"type":"module","title":"Supabase.Storage.Error","doc":"Represents an error response from Storage service","ref":"Supabase.Storage.Error.html"},{"type":"function","title":"Supabase.Storage.Error.from/2","doc":"","ref":"Supabase.Storage.Error.html#from/2"},{"type":"module","title":"Supabase.Storage.File","doc":"Represents an Object within a Supabase Storage Bucket.\n\nThis module encapsulates the structure and operations related to an object or file stored within a Supabase Storage bucket.","ref":"Supabase.Storage.File.html"},{"type":"function","title":"Supabase.Storage.File.copy/2","doc":"Copies an existing file to a new path in the same bucket.","ref":"Supabase.Storage.File.html#copy/2"},{"type":"function","title":"Params - Supabase.Storage.File.copy/2","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `options.from`: The original file path, including the current file name. For example `folder/image.png`.\n- `options.to`: The new file path, including the new file name. For example `folder/image-new.png`.\n- `options.destination_bucket`: The destination bucket ID to move the file if the `options.to` param refers to another bucket.","ref":"Supabase.Storage.File.html#copy/2-params"},{"type":"function","title":"Supabase.Storage.File.create_signed_upload_url/3","doc":"Creates a signed upload URL.\n\nSigned upload URLs can be used to upload files to the bucket without further authentication.\n\nThey are valid for 2 hours.","ref":"Supabase.Storage.File.html#create_signed_upload_url/3"},{"type":"function","title":"Params - Supabase.Storage.File.create_signed_upload_url/3","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `obejct_path`: The file path, including the current file name. For example `folder/image.png`.\n- `options.upsert`: If set to true, allows the file to be overwritten if it already exists.","ref":"Supabase.Storage.File.html#create_signed_upload_url/3-params"},{"type":"function","title":"Supabase.Storage.File.create_signed_url/3","doc":"Creates a signed URL. Use a signed URL to share a file for a fixed amount of time.","ref":"Supabase.Storage.File.html#create_signed_url/3"},{"type":"function","title":"Params - Supabase.Storage.File.create_signed_url/3","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `object_path`:The file path, including the current file name. For example `folder/image.png`.\n- `options.expires_in`: The number of seconds until the signed URL expires. For example, `60` for a URL which is valid for one minute.\n- `options.download`: Triggers the file as a download if set to true. Set this parameter as the name of the file if you want to trigger the download with a different filename.\n- `options.transform`: An `Enumerable` that represents the `Supabase.Storage.TransformOptions` to transform the asset before serving it to the client.","ref":"Supabase.Storage.File.html#create_signed_url/3-params"},{"type":"function","title":"Supabase.Storage.File.download/3","doc":"Downloads a file from a private bucket. For public buckets, make a request to the URL returned from `getPublicUrl` instead.","ref":"Supabase.Storage.File.html#download/3"},{"type":"function","title":"Params - Supabase.Storage.File.download/3","doc":"- `path`: The full path and file name of the file to be downloaded. For example `folder/image.png`.\n- `options.transform`: Transform the asset before serving it to the client.","ref":"Supabase.Storage.File.html#download/3-params"},{"type":"function","title":"Supabase.Storage.File.download_lazy/4","doc":"Downloads a file from a private bucket, lazily. For public buckets, make a request to the URL returned from `getPublicUrl` instead.","ref":"Supabase.Storage.File.html#download_lazy/4"},{"type":"function","title":"Params - Supabase.Storage.File.download_lazy/4","doc":"- `path`: The full path and file name of the file to be downloaded. For example `folder/image.png`.\n- `options.transform`: Transform the asset before serving it to the client.","ref":"Supabase.Storage.File.html#download_lazy/4-params"},{"type":"function","title":"Supabase.Storage.File.exists?/2","doc":"Checks the existence of a file.","ref":"Supabase.Storage.File.html#exists?/2"},{"type":"function","title":"Params - Supabase.Storage.File.exists?/2","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `path`","ref":"Supabase.Storage.File.html#exists?/2-params"},{"type":"function","title":"Supabase.Storage.File.get_public_url/3","doc":"A simple convenience function to get the URL for an asset in a public bucket. If you do not want to use this function, you can construct the public URL by concatenating the bucket URL with the path to the asset.\n\nThis function does not verify if the bucket is public. If a public URL is created for a bucket which is not public, you will not be able to download the asset.","ref":"Supabase.Storage.File.html#get_public_url/3"},{"type":"function","title":"Params - Supabase.Storage.File.get_public_url/3","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `path`: The path and name of the file to generate the public URL for. For example `folder/image.png`.\n- `options.download`: Triggers the file as a download if set to true. Set this parameter as the name of the file if you want to trigger the download with a different filename.\n- `options.transform`: `Supabase.Storage.TransformOptions` the asset before serving it to the client, as an `Enumerable`.","ref":"Supabase.Storage.File.html#get_public_url/3-params"},{"type":"function","title":"Supabase.Storage.File.info/2","doc":"Retrieves the details of an existing file.","ref":"Supabase.Storage.File.html#info/2"},{"type":"function","title":"Params - Supabase.Storage.File.info/2","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `path`","ref":"Supabase.Storage.File.html#info/2-params"},{"type":"function","title":"Supabase.Storage.File.list/3","doc":"Lists all the files within a bucket.","ref":"Supabase.Storage.File.html#list/3"},{"type":"function","title":"Params - Supabase.Storage.File.list/3","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `prefix`: The folder path.\n- `options`: An `Enumerable` that represents the `Elixir.Supabase.Storage.SearchOptions`.","ref":"Supabase.Storage.File.html#list/3-params"},{"type":"function","title":"Supabase.Storage.File.move/2","doc":"Moves an existing file to a new path in the same bucket.","ref":"Supabase.Storage.File.html#move/2"},{"type":"function","title":"Params - Supabase.Storage.File.move/2","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `options.from`: The original file path, including the current file name. For example `folder/image.png`.\n- `options.to`: The new file path, including the new file name. For example `folder/image-new.png`.\n- `options.destination_bucket`: The destination bucket ID to move the file if the `options.to` param refers to another bucket.","ref":"Supabase.Storage.File.html#move/2-params"},{"type":"function","title":"Supabase.Storage.File.remove/2","doc":"Deletes files within the same bucket","ref":"Supabase.Storage.File.html#remove/2"},{"type":"function","title":"Params - Supabase.Storage.File.remove/2","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `paths`: An array of files to delete, including the path and file name. For example `[\"folder/image.png\"]`.","ref":"Supabase.Storage.File.html#remove/2-params"},{"type":"type","title":"Supabase.Storage.File.t/0","doc":"An `Object` has the following attributes:\n\n- `id`: The unique identifier for the object.\n- `path`: The path to the object within its storage bucket.\n- `bucket_id`: The ID of the bucket that houses this object.\n- `name`: The name or title of the object.\n- `owner`: The owner or uploader of the object.\n- `metadata`: A map containing meta-information about the object (e.g., file type, size).\n- `created_at`: Timestamp indicating when the object was first uploaded or created.\n- `updated_at`: Timestamp indicating the last time the object was updated.\n- `last_accessed_at`: Timestamp of when the object was last accessed or retrieved.","ref":"Supabase.Storage.File.html#t:t/0"},{"type":"function","title":"Supabase.Storage.File.upload/4","doc":"Uploads a file to an existing bucket.","ref":"Supabase.Storage.File.html#upload/4"},{"type":"function","title":"Params - Supabase.Storage.File.upload/4","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `file_path`: The **local** filesystem path, to upload from.\n- `object_path`: The file path, including the file name. Should be of the format `folder/subfolder/filename.png`. The bucket must already exist before attempting to upload.\n- `options`: Optional `Enumerable` that represents the `Supabase.Storage.FileOptions`.","ref":"Supabase.Storage.File.html#upload/4-params"},{"type":"function","title":"Supabase.Storage.File.upload_to_signed_url/5","doc":"Upload a file with a token generated from `create_signed_upload_url/3`.","ref":"Supabase.Storage.File.html#upload_to_signed_url/5"},{"type":"function","title":"Params - Supabase.Storage.File.upload_to_signed_url/5","doc":"- `storage`: The `Supabase.Storage` instance created with `Supabase.Storage.from/2`.\n- `token`: token The token generated from `create_signed_upload_url/3`.\n- `file_path`: The **local** filesystem path, to upload from.\n- `object_path`: The file path, including the file name. Should be of the format `folder/subfolder/filename.png`. The bucket must already exist before attempting to upload.\n- `options`: Optional `Enumerable` that represents the `Supabase.Storage.FileOptions`.","ref":"Supabase.Storage.File.html#upload_to_signed_url/5-params"},{"type":"module","title":"Supabase.Storage.FileHandler","doc":"A low-level API interface for managing objects within a Supabase bucket.","ref":"Supabase.Storage.FileHandler.html"},{"type":"module","title":"Responsibilities - Supabase.Storage.FileHandler","doc":"- **File Management**: Create, move, copy, and get information about files in a bucket.\n- **Object Listing**: List objects based on certain criteria, like a prefix.\n- **Object Removal**: Delete specific objects or a list of objects.\n- **URL Management**: Generate signed URLs for granting temporary access to objects.\n- **Content Access**: Retrieve the content of an object or stream it.","ref":"Supabase.Storage.FileHandler.html#module-responsibilities"},{"type":"module","title":"Usage Warning - Supabase.Storage.FileHandler","doc":"This module is meant for internal use or for developers requiring more control over object management in Supabase. In general, users should work with the higher-level Supabase.Storage API when possible, as it may offer better abstractions and safety mechanisms.\n\nDirectly interfacing with this module bypasses any additional logic the main API might provide. Use it with caution and ensure you understand its operations.","ref":"Supabase.Storage.FileHandler.html#module-usage-warning"},{"type":"type","title":"Supabase.Storage.FileHandler.bucket_id/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:bucket_id/0"},{"type":"function","title":"Supabase.Storage.FileHandler.copy/5","doc":"","ref":"Supabase.Storage.FileHandler.html#copy/5"},{"type":"function","title":"Supabase.Storage.FileHandler.create_file/5","doc":"","ref":"Supabase.Storage.FileHandler.html#create_file/5"},{"type":"function","title":"Supabase.Storage.FileHandler.create_file_to_url/6","doc":"","ref":"Supabase.Storage.FileHandler.html#create_file_to_url/6"},{"type":"function","title":"Supabase.Storage.FileHandler.create_signed_url/4","doc":"","ref":"Supabase.Storage.FileHandler.html#create_signed_url/4"},{"type":"function","title":"Supabase.Storage.FileHandler.create_upload_signed_url/4","doc":"","ref":"Supabase.Storage.FileHandler.html#create_upload_signed_url/4"},{"type":"function","title":"Supabase.Storage.FileHandler.exists/3","doc":"","ref":"Supabase.Storage.FileHandler.html#exists/3"},{"type":"type","title":"Supabase.Storage.FileHandler.file_path/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:file_path/0"},{"type":"function","title":"Supabase.Storage.FileHandler.get/4","doc":"","ref":"Supabase.Storage.FileHandler.html#get/4"},{"type":"function","title":"Supabase.Storage.FileHandler.get_info/3","doc":"","ref":"Supabase.Storage.FileHandler.html#get_info/3"},{"type":"function","title":"Supabase.Storage.FileHandler.get_lazy/4","doc":"","ref":"Supabase.Storage.FileHandler.html#get_lazy/4"},{"type":"function","title":"Supabase.Storage.FileHandler.get_lazy/5","doc":"","ref":"Supabase.Storage.FileHandler.html#get_lazy/5"},{"type":"function","title":"Supabase.Storage.FileHandler.list/4","doc":"","ref":"Supabase.Storage.FileHandler.html#list/4"},{"type":"function","title":"Supabase.Storage.FileHandler.move/5","doc":"","ref":"Supabase.Storage.FileHandler.html#move/5"},{"type":"type","title":"Supabase.Storage.FileHandler.object_path/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:object_path/0"},{"type":"type","title":"Supabase.Storage.FileHandler.opts/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:opts/0"},{"type":"type","title":"Supabase.Storage.FileHandler.prefix/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:prefix/0"},{"type":"function","title":"Supabase.Storage.FileHandler.remove_list/3","doc":"","ref":"Supabase.Storage.FileHandler.html#remove_list/3"},{"type":"type","title":"Supabase.Storage.FileHandler.search_opts/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:search_opts/0"},{"type":"type","title":"Supabase.Storage.FileHandler.token/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:token/0"},{"type":"type","title":"Supabase.Storage.FileHandler.wildcard/0","doc":"","ref":"Supabase.Storage.FileHandler.html#t:wildcard/0"},{"type":"module","title":"Supabase.Storage.FileOptions","doc":"Represents the configurable options for an File within Supabase Storage.\n\nThis module encapsulates options that can be set or modified for a storage object. These options help in controlling behavior such as caching, content type, and whether to upsert an object.","ref":"Supabase.Storage.FileOptions.html"},{"type":"function","title":"Supabase.Storage.FileOptions.parse/1","doc":"","ref":"Supabase.Storage.FileOptions.html#parse/1"},{"type":"type","title":"Supabase.Storage.FileOptions.t/0","doc":"An `FileOptions` consists of the following attributes:\n\n- `cache_control`: The number of seconds the asset is cached in the browser and in the Supabase CDN. This is set in the `Cache-Control: max-age= ` header. Defaults to 3600 seconds.\n- `content_type`: Specifies the media type of the resource or data. Default is `\"text/plain;charset=UTF-8\"`.\n- `upsert`: When upsert is set to true, the file is overwritten if it exists. When set to false, an error is thrown if the object already exists. Defaults to false.\n- `metadata`: The metadata option is an object that allows you to store additional information about the file. This information can be used to filter and search for files. The metadata object can contain any key-value pairs you want to store.\n- `headers`: Optionally add extra headers to the request.","ref":"Supabase.Storage.FileOptions.html#t:t/0"},{"type":"module","title":"Supabase.Storage.Object","doc":"Represents an Object within a Supabase Storage Bucket.\n\nThis module encapsulates the structure and operations related to an object or file stored within a Supabase Storage bucket.","ref":"Supabase.Storage.Object.html"},{"type":"module","title":"Structure - Supabase.Storage.Object","doc":"An `Object` has the following attributes:\n\n- `id`: The unique identifier for the object.\n- `path`: The path to the object within its storage bucket.\n- `bucket_id`: The ID of the bucket that houses this object.\n- `name`: The name or title of the object.\n- `owner`: The owner or uploader of the object.\n- `metadata`: A map containing meta-information about the object (e.g., file type, size).\n- `created_at`: Timestamp indicating when the object was first uploaded or created.\n- `updated_at`: Timestamp indicating the last time the object was updated.\n- `last_accessed_at`: Timestamp of when the object was last accessed or retrieved.","ref":"Supabase.Storage.Object.html#module-structure"},{"type":"module","title":"Functions - Supabase.Storage.Object","doc":"- `parse!/1`: Accepts a map of attributes and constructs a structured `Object`.","ref":"Supabase.Storage.Object.html#module-functions"},{"type":"module","title":"Examples - Supabase.Storage.Object","doc":"","ref":"Supabase.Storage.Object.html#module-examples"},{"type":"module","title":"Parsing an object - Supabase.Storage.Object","doc":"object_attrs = %{\n      id: \"obj_id\",\n      path: \"/folder/my_file.txt\",\n      bucket_id: \"bucket_123\",\n      ...\n    }\n    Supabase.Storage.Object.parse!(object_attrs)","ref":"Supabase.Storage.Object.html#module-parsing-an-object"},{"type":"function","title":"Supabase.Storage.Object.parse/1","doc":"","ref":"Supabase.Storage.Object.html#parse/1"},{"type":"type","title":"Supabase.Storage.Object.t/0","doc":"","ref":"Supabase.Storage.Object.html#t:t/0"},{"type":"module","title":"Supabase.Storage.Request","doc":"Helper to build the base request builder for Storage services","ref":"Supabase.Storage.Request.html"},{"type":"function","title":"Supabase.Storage.Request.base/2","doc":"","ref":"Supabase.Storage.Request.html#base/2"},{"type":"module","title":"Supabase.Storage.SearchOptions","doc":"Represents the search options for querying objects within Supabase Storage.\n\nThis module encapsulates various options that aid in fetching and sorting storage objects. These options include specifying the limit on the number of results, an offset for pagination, and a sorting directive.","ref":"Supabase.Storage.SearchOptions.html"},{"type":"function","title":"Supabase.Storage.SearchOptions.parse/1","doc":"","ref":"Supabase.Storage.SearchOptions.html#parse/1"},{"type":"type","title":"Supabase.Storage.SearchOptions.t/0","doc":"An `SearchOptions` consists of the following attributes:\n\n- `limit`: The number of files you want to be returned.\n- `offset`: The starting position.\n- `sort_by`: The column to sort by. Can be any column inside a `Supabase.Storage.File`.\n- `search`: The search string to filter files by.","ref":"Supabase.Storage.SearchOptions.html#t:t/0"},{"type":"module","title":"Supabase.Storage.SearchOptions.SortBy","doc":"","ref":"Supabase.Storage.SearchOptions.SortBy.html"},{"type":"module","title":"Supabase.Storage.TransformOptions","doc":"Represents the transform options for querying objects within Supabase Storage.","ref":"Supabase.Storage.TransformOptions.html"},{"type":"function","title":"Supabase.Storage.TransformOptions.parse/1","doc":"","ref":"Supabase.Storage.TransformOptions.html#parse/1"},{"type":"type","title":"Supabase.Storage.TransformOptions.t/0","doc":"An `TransformOptions` consists of the following attributes:\n\n- `width`: The width of the image in pixels.\n- `height`: The height of the image in pixels.\n- `resize`: The resize mode can be cover, contain or fill. Defaults to cover. Cover resizes the image to maintain it's aspect ratio while filling the entire width and height. Contain resizes the image to maintain it's aspect ratio while fitting the entire image within the width and height. Fill resizes the image to fill the entire width and height. If the object's aspect ratio does not match the width and height, the image will be stretched to fit.\n- `quality`: Set the quality of the returned image. A number from 20 to 100, with 100 being the highest quality. Defaults to 80\n- `format`: Specify the format of the image requested. When using 'origin' we force the format to be the same as the original image. When this option is not passed in, images are optimized to modern image formats like Webp.","ref":"Supabase.Storage.TransformOptions.html#t:t/0"},{"type":"extras","title":"Supabase Storage","doc":"# Supabase Storage\n\n[Storage](https://supabase.com/docs/guides/storage) implementation for the [Supabase Potion](https://hexdocs.pm/supabase_potion) SDK in Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Supabase Storage","doc":"```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.6\"},\n    {:supabase_storage, \"~> 0.4\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Supabase Storage","doc":"Firstly you need to initialize your Supabase client(s) as can be found on the [Supabase Potion documentation](https://hexdocs.pm/supabase_potion/readme.html#usage)\n\nNow you can pass the Client to the `Supabase.Storage` functions:\n\n```elixir\niex> Supabase.Storage.list_buckets(%Supabase.Client{})\n```","ref":"readme.html#usage"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}